Cache

Struct Cache 

pub struct Cache<K: Eq + Hash + 'static, V: 'static> { /* private fields */ }
The Cache interface. Store within a LazyLock, and pass the corresponding CacheStatic to the LazyLock::new()

Implementations

Source

impl<K: Eq + Hash + Clone + 'static, V: 'static> Cache<K, V>

pub fn new(container: &'static CacheStatic<K, V>) -> Self

Construct a new Cache. This should be provided to the LazyLock holding this object.

Example
use common::cache::{CacheStatic, Cache};
use dashmap::DashMap;
use std::{
    borrow::Cow,
    sync::LazyLock
};

static CACHE: CacheStatic<String, Cow<'static, str>> = LazyLock::new(DashMap::default);
pub static MY_CACHE: LazyLock<Cache<String, Cow<'static, str>>> = LazyLock::new(|| Cache::new(&CACHE));
pub fn get<R>(&self, key: &R) -> Option<&'static V>
where R: ?Sized + Hash + Eq, K: Borrow<R>,

Get a value from within the Cache, if it exists.

Example
use common::cache::{CacheStatic, Cache};
use dashmap::DashMap;
use std::{
    borrow::Cow,
    sync::LazyLock
};

static CACHE: CacheStatic<String, Cow<'static, str>> = LazyLock::new(DashMap::default);
pub static MY_CACHE: LazyLock<Cache<String, Cow<'static, str>>> = LazyLock::new(|| Cache::new(&CACHE));

MY_CACHE.insert("Test".to_string(), Cow::Borrowed("Another"));
let value: &'static str = MY_CACHE.get("Test").unwrap();
assert!(value == "Another");
pub fn insert(&self, key: K, value: V) -> &'static V

Insert a new value into the Cache, returning the stored value.

Example
use common::cache::{CacheStatic, Cache};
use dashmap::DashMap;
use std::{
    borrow::Cow,
    sync::LazyLock
};

static CACHE: CacheStatic<String, Cow<'static, str>> = LazyLock::new(DashMap::default);
pub static MY_CACHE: LazyLock<Cache<String, Cow<'static, str>>> = LazyLock::new(|| Cache::new(&CACHE));

let interior: &'static str = MY_CACHE.insert("Test".to_string(), Cow::Borrowed("Another"));
assert!(interior == "Another");